pub unsafe trait NonNullable { }Expand description
Marker trait for types subject to the null pointer optimization.
Safety
If zeroed is a valid bitpattern, undefined behavior will occur when trying to optimize memory.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".